# YouTrack MCP Documentation

## Documentation Structure

- [Architecture](./ARCHITECTURE.md) - System architecture and design
- [Development Guide](./DEVELOPMENT.md) - Development setup with UV

## Quick Start

For development setup, see [Development Guide](./DEVELOPMENT.md).

## API Documentation

The YouTrack MCP Server provides tools for:
- Issue management
- Project management  
- User management
- Search functionality

See [Architecture](./ARCHITECTURE.md) for detailed API structure.